Index: pkg/analysis_server/lib/plugin/index.dart |
diff --git a/pkg/analysis_server/lib/plugin/fix.dart b/pkg/analysis_server/lib/plugin/index.dart |
similarity index 61% |
copy from pkg/analysis_server/lib/plugin/fix.dart |
copy to pkg/analysis_server/lib/plugin/index.dart |
index a89b84738cb5957ee1afd190df31dd8553c88791..a6af762dbfa78bfd4a4e1ed69d0d6a67c3ac19b4 100644 |
--- a/pkg/analysis_server/lib/plugin/fix.dart |
+++ b/pkg/analysis_server/lib/plugin/index.dart |
@@ -3,20 +3,20 @@ |
// BSD-style license that can be found in the LICENSE file. |
/** |
* Support for client code that extends the analysis server by adding new fix |
* contributors. |
*/ |
-library analysis_server.plugin.fix; |
+library analysis_server.plugin.index; |
-import 'package:analysis_server/edit/fix/fix_core.dart'; |
+import 'package:analysis_server/analysis/index/index_core.dart'; |
import 'package:analysis_server/src/plugin/server_plugin.dart'; |
import 'package:analyzer/plugin/plugin.dart'; |
/** |
* The identifier of the extension point that allows plugins to register new |
* fix contributors with the server. The object used as an extension must be a |
* [FixContributor]. |
*/ |
-final String FIX_CONTRIBUTOR_EXTENSION_POINT_ID = Plugin.join( |
+final String INDEX_CONTRIBUTOR_EXTENSION_POINT_ID = Plugin.join( |
ServerPlugin.UNIQUE_IDENTIFIER, |
- ServerPlugin.FIX_CONTRIBUTOR_EXTENSION_POINT); |
+ ServerPlugin.INDEX_CONTRIBUTOR_EXTENSION_POINT); |
@@ -3,20 +3,20 @@ |
// BSD-style license that can be found in the LICENSE file. |
/** |
- * Support for client code that extends the analysis server by adding new fix |
+ * Support for client code that extends the analysis server by adding new index |
* contributors. |
*/ |
@@ -3,20 +3,20 @@ |
/** |
* The identifier of the extension point that allows plugins to register new |
- * fix contributors with the server. The object used as an extension must be a |
- * [FixContributor]. |
+ * index contributors with the server. The object used as an extension must be |
+ * an [IndexContributor]. |
*/ |